@@ -20,9 +20,9 @@
 
 """VAT (Moms, Mervärdesskatt, Swedish VAT number).
 
-The Momsregistreringsnummer is used for VAT (Moms, Mervärdesskatt)
-purposes and consists of 12 digits of which the last two should be 01. The
-first 10 digits should have a valid Luhn checksum.
+The Momsregistreringsnummer is used for VAT (Moms, Mervärdesskatt) purposes
+and consists of 12 digits of which the last two should be 01. The first 10
+digits should have a valid Luhn checksum.
 
 >>> validate('SE 123456789701')
 '123456789701'
@@ -32,8 +32,8 @@ Traceback (most recent call last):
 InvalidChecksum: ...
 """
 
-from stdnum import luhn
 from stdnum.exceptions import *
+from stdnum.se import orgnr
 from stdnum.util import clean
 
 
@@ -47,20 +47,17 @@ def compact(number):
 
 
 def validate(number):
-    """Checks to see if the number provided is a valid VAT number. This
-    checks the length, formatting and check digit."""
+    """Check if the number is a valid VAT number. This checks the length,
+    formatting and check digit."""
     number = compact(number)
     if not number.isdigit() or number[-2:] != '01':
         raise InvalidFormat()
-    if len(number) != 12:
-        raise InvalidLength()
-    luhn.validate(number[:-2])
+    orgnr.validate(number[:-2])
     return number
 
 
 def is_valid(number):
-    """Checks to see if the number provided is a valid VAT number. This
-    checks the length, formatting and check digit."""
+    """Check if the number is a valid VAT number."""
     try:
         return bool(validate(number))
     except ValidationError:
